// Copyright (C) 1998-2019 by Northwoods Software Corporation. All Rights Reserved.
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var tslib = require('tslib');
var go = require('gojs');
var React = require('react');

var ReactDiagram = (function (_super) {
    tslib.__extends(ReactDiagram, _super);
    function ReactDiagram(props) {
        var _this = _super.call(this, props) || this;
        _this.modelChangedListener = null;
        _this.divRef = React.createRef();
        return _this;
    }
    ReactDiagram.prototype.getDiagram = function () {
        if (this.divRef.current === null)
            return null;
        return go.Diagram.fromDiv(this.divRef.current);
    };
    ReactDiagram.prototype.componentDidMount = function () {
        var _this = this;
        if (this.divRef.current === null)
            return;
        var diagram = this.props.initDiagram();
        diagram.div = this.divRef.current;
        diagram.delayInitialization(function () {
            var model = diagram.model;
            model.commit(function (m) {
                m.mergeNodeDataArray(m.cloneDeep(_this.props.nodeDataArray));
                if (_this.props.linkDataArray !== undefined && m instanceof go.GraphLinksModel) {
                    m.mergeLinkDataArray(m.cloneDeep(_this.props.linkDataArray));
                }
                if (_this.props.modelData !== undefined) {
                    m.assignAllDataProperties(m.modelData, _this.props.modelData);
                }
            }, null);
        });
        this.modelChangedListener = function (e) {
            if (e.isTransactionFinished) {
                var dataChanges = e.model.toIncrementalData(e);
                if (dataChanges !== null)
                    _this.props.onModelChange(dataChanges);
            }
        };
        diagram.addModelChangedListener(this.modelChangedListener);
    };
    ReactDiagram.prototype.componentWillUnmount = function () {
        var diagram = this.getDiagram();
        if (diagram !== null) {
            diagram.div = null;
            if (this.modelChangedListener !== null) {
                diagram.removeModelChangedListener(this.modelChangedListener);
                this.modelChangedListener = null;
            }
        }
    };
    ReactDiagram.prototype.shouldComponentUpdate = function (nextProps, nextState) {
        if (nextProps.skipsDiagramUpdate)
            return false;
        if (nextProps.nodeDataArray === this.props.nodeDataArray &&
            nextProps.linkDataArray === this.props.linkDataArray &&
            nextProps.modelData === this.props.modelData)
            return false;
        return true;
    };
    ReactDiagram.prototype.componentDidUpdate = function (prevProps, prevState) {
        var diagram = this.getDiagram();
        if (diagram !== null) {
            var model = diagram.model;
            if (this.modelChangedListener !== null)
                model.removeChangedListener(this.modelChangedListener);
            model.startTransaction('update data');
            model.mergeNodeDataArray(model.cloneDeep(this.props.nodeDataArray));
            if (this.props.linkDataArray !== undefined && model instanceof go.GraphLinksModel) {
                model.mergeLinkDataArray(model.cloneDeep(this.props.linkDataArray));
            }
            if (this.props.modelData !== undefined) {
                model.assignAllDataProperties(model.modelData, this.props.modelData);
            }
            model.commitTransaction('update data');
            if (this.modelChangedListener !== null)
                model.addChangedListener(this.modelChangedListener);
        }
    };
    ReactDiagram.prototype.render = function () {
        return (React.createElement("div", { ref: this.divRef, className: this.props.divClassName }));
    };
    return ReactDiagram;
}(React.Component));

var ReactOverview = (function (_super) {
    tslib.__extends(ReactOverview, _super);
    function ReactOverview(props) {
        var _this = _super.call(this, props) || this;
        _this.divRef = React.createRef();
        return _this;
    }
    ReactOverview.prototype.getOverview = function () {
        if (this.divRef.current === null)
            return null;
        return go.Diagram.fromDiv(this.divRef.current);
    };
    ReactOverview.prototype.componentDidMount = function () {
        if (this.divRef.current === null)
            return;
        var overview;
        if (this.props.initOverview !== undefined) {
            overview = this.props.initOverview();
        }
        else {
            overview = new go.Overview();
            overview.contentAlignment = go.Spot.Center;
        }
        overview.div = this.divRef.current;
        overview.observed = this.props.observedDiagram;
    };
    ReactOverview.prototype.componentWillUnmount = function () {
        var overview = this.getOverview();
        if (overview !== null) {
            overview.div = null;
            overview.observed = null;
        }
    };
    ReactOverview.prototype.shouldComponentUpdate = function (nextProps, nextState) {
        if (nextProps.observedDiagram === this.props.observedDiagram)
            return false;
        return true;
    };
    ReactOverview.prototype.componentDidUpdate = function (prevProps, prevState) {
        var overview = this.getOverview();
        if (overview !== null) {
            overview.observed = this.props.observedDiagram;
        }
    };
    ReactOverview.prototype.render = function () {
        return (React.createElement("div", { ref: this.divRef, className: this.props.divClassName }));
    };
    return ReactOverview;
}(React.Component));

var ReactPalette = (function (_super) {
    tslib.__extends(ReactPalette, _super);
    function ReactPalette(props) {
        var _this = _super.call(this, props) || this;
        _this.divRef = React.createRef();
        return _this;
    }
    ReactPalette.prototype.getPalette = function () {
        if (this.divRef.current === null)
            return null;
        return go.Diagram.fromDiv(this.divRef.current);
    };
    ReactPalette.prototype.componentDidMount = function () {
        var _this = this;
        if (this.divRef.current === null)
            return;
        var palette = this.props.initPalette();
        palette.div = this.divRef.current;
        palette.delayInitialization(function () {
            var model = palette.model;
            model.commit(function (m) {
                m.mergeNodeDataArray(m.cloneDeep(_this.props.nodeDataArray));
                if (_this.props.linkDataArray !== undefined && m instanceof go.GraphLinksModel) {
                    m.mergeLinkDataArray(m.cloneDeep(_this.props.linkDataArray));
                }
                if (_this.props.modelData !== undefined) {
                    m.assignAllDataProperties(m.modelData, _this.props.modelData);
                }
            }, null);
        });
    };
    ReactPalette.prototype.componentWillUnmount = function () {
        var palette = this.getPalette();
        if (palette !== null) {
            palette.div = null;
        }
    };
    ReactPalette.prototype.shouldComponentUpdate = function (nextProps, nextState) {
        if (nextProps.nodeDataArray === this.props.nodeDataArray &&
            nextProps.linkDataArray === this.props.linkDataArray &&
            nextProps.modelData === this.props.modelData)
            return false;
        return true;
    };
    ReactPalette.prototype.componentDidUpdate = function (prevProps, prevState) {
        var palette = this.getPalette();
        if (palette !== null) {
            var model = palette.model;
            model.startTransaction('update data');
            model.mergeNodeDataArray(model.cloneDeep(this.props.nodeDataArray));
            if (this.props.linkDataArray !== undefined && model instanceof go.GraphLinksModel) {
                model.mergeLinkDataArray(model.cloneDeep(this.props.linkDataArray));
            }
            if (this.props.modelData !== undefined) {
                model.assignAllDataProperties(model.modelData, this.props.modelData);
            }
            model.commitTransaction('update data');
        }
    };
    ReactPalette.prototype.render = function () {
        return (React.createElement("div", { ref: this.divRef, className: this.props.divClassName }));
    };
    return ReactPalette;
}(React.Component));

exports.ReactDiagram = ReactDiagram;
exports.ReactOverview = ReactOverview;
exports.ReactPalette = ReactPalette;
